##
##  postgresql-odbc.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         postgresql-odbc
Summary:      PostgreSQL Extension: ODBC Driver
URL:          https://odbc.postgresql.org/
Vendor:       Christian Czezatke, Dan McGuirk, Julie Ann Case
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      LGPL
Version:      15.00.0000
Release:      20230625

#   list of sources
Source0:      https://ftp.postgresql.org/pub/odbc/versions/src/psqlodbc-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  postgresql, unixodbc
PreReq:       postgresql, unixodbc

%description
    This is a PostgreSQL extension providing its ODBC Driver.

%track
    prog postgresql-odbc = {
        version   = %{version}
        url       = http://www.postgresql.org/ftp/odbc/versions/src/
        regex     = psqlodbc-(\d\d\.\d\d\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n psqlodbc-%{version}

%build
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lssl -lcrypto" \
    ./configure \
        --prefix=%{l_prefix} \
        --with-unixodbc=%{l_prefix}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

%post
    if [ $1 -eq 2 ]; then
        if ! $RPM_INSTALL_PREFIX/bin/odbcinst -q -d -n "PostgreSQL" >/dev/null 2>&1; then
            ( echo "[PostgreSQL]"
              echo "Description = PostgreSQL ODBC driver"
              echo "Driver      = $RPM_INSTALL_PREFIX/lib/psqlodbcw.so"
              echo "Threading   = 2"
            ) | $RPM_INSTALL_PREFIX/bin/odbcinst -i -d -r -n "PostgreSQL"
        fi
    fi
    exit 0

%preun
    if [ $1 -eq 0 ]; then
        $RPM_INSTALL_PREFIX/bin/odbcinst -u -d -n "PostgreSQL"
    fi
    exit 0

